# Unpack.AI
> The Unpack.AI library, through dedication and simple engineering, empower your business / career with state-of-the-art deep learning.


## Installation


You can install this library with pip
```
pip install unpackai
```

or with github link
```shell
pip install git+https://github.com/raynardj/unpackai/
```
